@@ -3,7 +3,7 @@ use warnings;
 use strict;
 
 # ABSTRACT: Tools for generating random Dutch numbers
-our $VERSION = '1.1';
+our $VERSION = '1.2';
 
 use Exporter qw(import);
 use Carp qw(croak);
@@ -87,7 +87,7 @@ sub generate_rsin {
 
     @rsin = _get_last_number(@rsin);
     return join("", @rsin) if @rsin;
-    return generate_rsin();
+    return generate_rsin($begin);
 }
 
 sub _get_last_number {
@@ -136,7 +136,7 @@ Data::Random::NL - Tools for generating random Dutch numbers
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 SYNOPSIS
 
